Classifier

Struct Classifier 

pub struct Classifier { /* private fields */ }
A random forest classifier.

Training

The Trainer implements CommonTrainerBuilder and EnsembleTrainerBuilder. Default training parameters:

max_depth: usize::MAX,
max_features: NumFeatures::SQRT,
seed: 42,
min_samples_leaf: 1,
min_samples_split: 2,
sample_weights: empty (1.0 for each sample)
num_trees: 100,
num_threads: 1,

Example

use rafor::rf;
let dataset = [0.7, 0.0, 0.8, 1.0, 0.7, 0.0];
let targets = [1, 5, 1];
let predictor = rf::Classifier::trainer().train(&dataset, &targets);
let predictions = predictor.predict(&dataset, 1);
assert_eq!(&predictions, &[1, 5, 1]);

Implementations

Source

impl Classifier

pub fn predict(&self, dataset: &[f32], num_threads: usize) -> Vec<i64>

Predicts classes for a set of samples using num_threads threads. Dataset is a vector of floats with length multiple of num_features().

pub fn predict_one(&self, sample: &[f32]) -> i64

Predicts class for a single sample given by a slice of length num_features().

pub fn proba(&self, dataset: &[f32], num_threads: usize) -> Vec<f32>

Predicts classes probabilities for each sample using num_threads threads. The length of result vector is number_of_samples * num_classes().

pub fn num_features(&self) -> usize

Returns a number of features for a trained tree.

pub fn trainer() -> Trainer

Provides trainer for training a random forest classifier.